@@ -220,29 +220,32 @@ CString CAddressView::GetFrom()
 
 BOOL CAddressView::PreTranslateMessage(MSG* pMsg) 
 {
-	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
-	if(pMsg->message == WM_CHAR){
-		if(df->Char(pMsg->wParam, this))
-			return TRUE;
-	}
-	if(pMsg->message == WM_KEYDOWN){
-
-		if(df->KeyDown(pMsg->wParam, this))
-			return TRUE;
-
-		if(pMsg->wParam == VK_TAB){
-			this->Complete();
-			return TRUE;
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	if(app->GetProfileInt("Customize", "MewKeyBind", 0)){
+		CDraftFrame* df = (CDraftFrame*)GetParentFrame();
+		if(pMsg->message == WM_CHAR){
+			if(df->Char(pMsg->wParam, this))
+				return TRUE;
 		}
-		else if(pMsg->wParam == VK_RETURN){
-			CEdit *edit = this->GetFocusedEditCtrl();
-			if(edit != NULL){
-				edit->SetSel(edit->GetWindowTextLength(), edit->GetWindowTextLength());
+		if(pMsg->message == WM_KEYDOWN){
+
+			if(df->KeyDown(pMsg->wParam, this))
+				return TRUE;
+
+			if(pMsg->wParam == VK_TAB){
+				this->Complete();
+				return TRUE;
+			}
+			else if(pMsg->wParam == VK_RETURN){
+				CEdit *edit = this->GetFocusedEditCtrl();
+				if(edit != NULL){
+					edit->SetSel(edit->GetWindowTextLength(), edit->GetWindowTextLength());
+				}
+				return TRUE;
+			}
+			else if(pMsg->wParam == 40/*pressing [PgDn] work as pressing [TAB]*/){
+				pMsg->wParam = VK_TAB;
 			}
-			return TRUE;
-		}
-		else if(pMsg->wParam == 40/*pressing [PgDn] work as pressing [TAB]*/){
-			pMsg->wParam = VK_TAB;
 		}
 	}
 	return CFormView::PreTranslateMessage(pMsg);
