@@ -44,10 +44,9 @@ CDraftFrame::CDraftFrame()
 {
 	CGpg gpg;
 	CPochyApp *app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
+//	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 	this->m_hide = FALSE;
 	this->m_flag = FALSE;
-//	this->m_account = mf->m_pAcntV->GetCurrentAccountName();
 	this->m_hide_attach = FALSE;
 	this->m_button_gpg = app->m_gpg_enable;
 	this->m_button_gpgenc = app->m_gpg_enable;
@@ -58,6 +57,7 @@ CDraftFrame::CDraftFrame()
 	this->m_button_savedraft = TRUE;
 	this->m_button_sendmail = TRUE;
 	this->m_send_dlg = NULL;
+	this->m_me.CopyFrom(&app->m_me);
 }
 
 CDraftFrame::~CDraftFrame()
@@ -144,14 +144,23 @@ int CDraftFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 
   	// get previous window position from ini fileini.
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
-	CRect rcWnd;
+	CRect rc;
 
 	// resurrect previous window position.
-	rcWnd.left = app->GetProfileInt("DraftWndPlace", "Left", 0);
-	rcWnd.top = app->GetProfileInt("DraftWndPlace", "Top", 0);
-	rcWnd.right = app->GetProfileInt("DraftWndPlace", "Right", 700);
-	rcWnd.bottom = app->GetProfileInt("DraftWndPlace", "Bottom", 520);
-	this->MoveWindow(rcWnd);
+	rc.left = app->GetProfileInt("DraftWndPlace", "Left", 0);
+	rc.top = app->GetProfileInt("DraftWndPlace", "Top", 0);
+	rc.right = app->GetProfileInt("DraftWndPlace", "Right", 700);
+	rc.bottom = app->GetProfileInt("DraftWndPlace", "Bottom", 520);
+
+	RECT rc2;
+	if(!::IsRectEmpty(&rc)){
+		SystemParametersInfo(SPI_GETWORKAREA, 0, &rc2, 0);
+		rc.left = rc.left+rc2.left;
+		rc.top = rc.top+rc2.top;
+		rc.right = rc.right+rc2.left;
+		rc.bottom = rc.bottom+rc2.top;
+		this->MoveWindow(rc);
+	}
 
 	return 0;
 }
@@ -216,8 +225,8 @@ void CDraftFrame::OnProgDestroy()
 
 BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext) 
 {
-	CPochyApp* app=(CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
+//	CPochyApp* app=(CPochyApp*)AfxGetApp();
+//	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
 	this->m_wndSplit.CreateStatic(this, 2, 1);
 	this->m_wndSplit.SetStaticBorder(TRUE);
@@ -232,7 +241,6 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 	this->m_pAddrsV = (CAddressView*)m_wndSplit1.GetPane(0, 0);
 	this->m_pEditV = (CMailEditView*)m_wndSplit1.GetPane(1, 0);
 	this->m_pListV2 = (CAttachedFileView*)m_wndSplit.GetPane(1, 0);
-	this->m_me.CopyFrom(&app->m_me);
 
 	// CAddressView̃TCY
 	CSize size = this->m_pAddrsV->GetTotalSize();
@@ -251,13 +259,6 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 
 	this->m_flag=TRUE;
 
-	// setting account name in window title.
-	// below is stupid, but cannot find out better way.
-//	CString title;
-//	CString account = mf->m_pAcntV->GetCurrentAccountName();
-//	title.Format("%s - %s", m_account, "draft");
-//	this->SetWindowText(title);
-
 	return TRUE;
 }
 
@@ -290,8 +291,8 @@ void CDraftFrame::OnAddFile()
 void CDraftFrame::OnSize(UINT nType, int cx, int cy) 
 {
 	CFrameWnd::OnSize(nType, cx, cy);
-	CPochyApp *app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
+//	CPochyApp *app = (CPochyApp*)AfxGetApp();
+//	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
 	if(this->m_flag)
 		this->ReArrangeSplit();
@@ -361,7 +362,7 @@ void CDraftFrame::RecoverIME(CView* view)
 
 BOOL CDraftFrame::KeyDown(UINT nChar,CView* view)
 {
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
+//	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CStatusBar& sb = this->m_wndStatusBar;
 	if(::GetKeyState(VK_CONTROL) & 0xff00){	// whether or not pressing CTRL
 		switch(nChar){
@@ -479,7 +480,7 @@ void CDraftFrame::OnGpgEnc()
 	CGpg gpg;
 
 	// selection of key.
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
+//	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CGpgKeyListDlg lkd(this);
 	CString recipient;
 	recipient.Empty();
@@ -533,7 +534,7 @@ void CDraftFrame::OnGpgExport()
 	CGpg gpg;
 
 	// selection of key.
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
+//	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CGpgKeyListDlg lkd;
 	if(lkd.DoModal()==IDOK && this->m_key_id_list.GetSize()){
 		// below may work under conditon that GpgKeyListDlg cannot accept multiple selection.
@@ -846,12 +847,18 @@ BOOL CDraftFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 
 void CDraftFrame::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
-	this->Char(nChar, NULL);
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	if(app->GetProfileInt("Customize", "MewKeyBind", 0)){
+		this->Char(nChar, NULL);
+	}
 	CFrameWnd::OnChar(nChar, nRepCnt, nFlags);
 }
 
 void CDraftFrame::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
-	this->KeyDown(nChar, NULL);
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	if(app->GetProfileInt("Customize", "MewKeyBind", 0)){
+		this->KeyDown(nChar, NULL);
+	}
 	CFrameWnd::OnKeyDown(nChar, nRepCnt, nFlags);
 }
