@@ -80,6 +80,8 @@ UINT FetchMail(LPVOID pParam)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
+	mf->StartTaskTrayAnimation();
+
 	// ݑIĂAJEg擾ĂB
 	CString account = (char *)pParam;
 
@@ -129,14 +131,17 @@ UINT FetchMail(LPVOID pParam)
 		// get password from ini file.
 		GetPrivateProfileString("pop", "pass", "", pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 		pass.ReleaseBuffer();
-		if(pass.IsEmpty() && !app->m_pop_passphrase.IsEmpty())
-			pass = app->m_pop_passphrase;
-		else if(pass.IsEmpty() && app->m_pop_passphrase.IsEmpty()){
+		if(pass.IsEmpty() && !mf->m_pAcntV->GetAccountPopPass(account).IsEmpty())
+			pass = mf->m_pAcntV->GetAccountPopPass(account);
+		else if(pass.IsEmpty() && mf->m_pAcntV->GetAccountPopPass(account).IsEmpty()){
 			// if getting no password from ini file, then show dialog for input password.
 			CPassPhraseDlg passDlg;
-			passDlg.SetFlag(POP);
-			passDlg.DoModal();
-			pass = app->m_pop_passphrase;
+			if(IDOK == passDlg.DoModal()){
+				pass = passDlg.GetPass();
+				mf->m_pAcntV->SetAccountPopPass(account, pass);
+			}else{
+				throw "";
+			}
 		}
 
 		if(GetPrivateProfileInt("pop", "apop", 0, path)){
@@ -149,6 +154,8 @@ UINT FetchMail(LPVOID pParam)
 				throw "error is occured in pass session";
 			if(buf.Find("-ERR") == 0 || buf.Find("-err") == 0){
 				message.Format("%s", buf.GetBuffer(0));
+				pass.Empty();
+				mf->m_pAcntV->SetAccountPopPass(account, pass);
 				throw message.GetBuffer(0);
 			}
 			buf = apop;
@@ -175,6 +182,8 @@ UINT FetchMail(LPVOID pParam)
 				throw "error is occured in pass session";
 			if(buf.Find("-ERR") == 0 || buf.Find("-err") == 0){
 				message.Format("%s", buf.GetBuffer(0));
+				pass.Empty();
+				mf->m_pAcntV->SetAccountPopPass(account, pass);
 				throw message.GetBuffer(0);
 			}
 			buf = "pass ********";
@@ -408,11 +417,14 @@ UINT FetchMail(LPVOID pParam)
 		// socket
 		pop_socket.DisConnect();
 		// vOXo[̃|WV0ɖ߂
-		mf->MessageBox(errorstr, account+" - pop error");
+		if(strlen(errorstr)){
+			mf->MessageBox(errorstr, account+" - pop error");
+		}
 		av->SetStatusBarProgress(0, 100, account);
 		av->SetStatusBarText("", account);
 		mf->UpdateButton(TRUE, account);
 		av->SetFetchStatus(account.GetBuffer(0), FALSE);
+		mf->StopTaskTrayAnimation();
 		return FALSE;
 	}
 
@@ -429,5 +441,7 @@ UINT FetchMail(LPVOID pParam)
 	addr.ReleaseBuffer();
 	buf.ReleaseBuffer();
 
+	mf->StopTaskTrayAnimation();
+
 	return TRUE;
 }
