@@ -256,7 +256,7 @@ void CFolderView::OnItemexpanded(NMHDR* pNMHDR, LRESULT* pResult)
 {
 	HTREEITEM ti;
 	CString path;
-	CTreeCtrl& treeCtrl = GetTreeCtrl();
+//	CTreeCtrl& treeCtrl = GetTreeCtrl();
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
 
@@ -365,7 +365,7 @@ void CFolderView::RefreshTree()
 void CFolderView::AddUser(CString path, CString user)
 {
 	CFileFind ff;
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
+//	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CSortStringArray DirArray;
 	CTreeCtrl& tc = GetTreeCtrl();
 	HTREEITEM hItem = tc.InsertItem(user, 3, 3, TVI_ROOT, TVI_FIRST);
@@ -550,7 +550,7 @@ void CFolderView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult)
 void CFolderView::OnMouseMove(UINT nFlags, CPoint point) 
 {
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
+//	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	HTREEITEM	hitem;
 	UINT		flags;
 
