@@ -210,17 +210,23 @@ void CMailEditView::OnInitialUpdate()
     app->GetProfileInt("EditViewColor", "BkColorR", DEF_BKG_COLOR_R),
     app->GetProfileInt("EditViewColor", "BkColorG", DEF_BKG_COLOR_G),
     app->GetProfileInt("EditViewColor", "BkColorB", DEF_BKG_COLOR_B)));
-	m_nWordWrap = WrapNone;
-	WrapChanged(); // ܂ԂȂ
+
+	if(!app->GetProfileInt("Customize", "WordWrap", 0)){
+		m_nWordWrap = WrapNone;
+		WrapChanged(); // ܂ԂȂ
+	}
 	r.SetOptions(ECOOP_OR,ECO_AUTOHSCROLL);
 }
 
 void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
 	TRACE("char=%d\n",nChar);
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
-	if(df->Char(nChar,this))
-		return;
+	if(app->GetProfileInt("Customize", "MewKeyBind", 0)){
+		if(df->Char(nChar,this))
+			return;
+	}
 
 	long a,b;
 	int y;
@@ -231,7 +237,7 @@ void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 	int li = r.LineIndex();
 	int pli = r.LineIndex(y-1);
 	int nli = r.LineIndex(y+1);
-	int len = r.LineLength();
+//	int len = r.LineLength();
 	int plen = r.LineLength(pli);
 	int nlen = r.LineLength(nli);
 
@@ -263,10 +269,12 @@ void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 
 void CMailEditView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
-
-	if(df->KeyDown(nChar,this))
-		return;
+	if(app->GetProfileInt("Customize", "MewKeyBind", 0)){
+		if(df->KeyDown(nChar,this))
+			return;
+	}
 	CRichEditView::OnKeyDown(nChar, nRepCnt, nFlags);
 }
 
@@ -605,7 +613,7 @@ void CMailEditView::OnEditviewUndo()
 
 int CMailEditView::GetPos()
 {
-	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
+//	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
 	CPoint p;
 	p = GetCaretPos();
 	return p.x/m_font_size-1;
