@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2002-2003 chik, s.hiranaka
+ * 2003-10-26 Some modification is done for task tray icon and the animation by minamina.
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -18,7 +19,6 @@
 #include "SettingAccountDlg.h"
 #include "lib.h"
 #include "MimeEncode.h"
-//#include "_regex.h"
 #include "Gpg.h"
 #include "PassPhraseDlg.h"
 #include "direct.h"			// _mkdir
@@ -32,11 +32,6 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
-#define WM_USER_NOTIFYICON (WM_APP + 100)
-#define TOOLBAR_MAIN_FILENAME _T("\\skin\\toolbar_main.bmp")
-#define TASKTRAY_ICON_FILENAME _T("\\skin\\tasktray.ico")
-#define NUMBER_OF_TOOLBAR_MAIN_ICON (10)
-
 /////////////////////////////////////////////////////////////////////////////
 // CMainFrame
 
@@ -106,6 +101,7 @@ CMainFrame::CMainFrame()
 	m_button_transfer = FALSE;
 	m_button_gpg_dec = FALSE;
 	m_button_info = FALSE;
+	m_tasktray_animation_num = 0;
 }
 
 CMainFrame::~CMainFrame()
@@ -143,14 +139,23 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 
 	// init@CÕEBhEʒu擾
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
-	CRect rcWnd;
-	
+	CRect rc;
+
 	// ÕEBhEʒu𕜌
-	rcWnd.left = app->GetProfileInt("wndPlace", "Left", 0);
-	rcWnd.top = app->GetProfileInt("wndPlace", "Top", 0);
-	rcWnd.right = app->GetProfileInt("wndPlace", "Right", 700);
-	rcWnd.bottom = app->GetProfileInt("wndPlace", "Bottom", 520);
-	MoveWindow(rcWnd);
+	rc.left = app->GetProfileInt("wndPlace", "Left", 0);
+	rc.top = app->GetProfileInt("wndPlace", "Top", 0);
+	rc.right = app->GetProfileInt("wndPlace", "Right", 700);
+	rc.bottom = app->GetProfileInt("wndPlace", "Bottom", 520);
+
+	RECT rc2;
+	if(!::IsRectEmpty(&rc)){
+		SystemParametersInfo(SPI_GETWORKAREA, 0, &rc2, 0);
+		rc.left = rc.left+rc2.left;
+		rc.top = rc.top+rc2.top;
+		rc.right = rc.right+rc2.left;
+		rc.bottom = rc.bottom+rc2.top;
+		MoveWindow(rc);
+	}
 
 	// resurrect status of bar
 	this->m_wndToolBar.ShowWindow(app->GetProfileInt("ToolBar", "IsVisible", SW_SHOW));
@@ -175,6 +180,10 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 	{
 		m_notifyIcon.Add();
 	}
+	// ^XNgCAj[Vݒ肷
+	CString strTaskTrayAnimationFilePath = app->m_app_path + TASKTRAY_ANIMATION_FILENAME;
+	m_notifyIcon.SetAnimation(strTaskTrayAnimationFilePath, 100, true,
+		RGB(255, 255, 255), TASKTRAY_ANIMATION_TIMER_ID);
 
 	return 0;
 }
@@ -331,9 +340,11 @@ void CMainFrame::OnGpgDec()
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	if(app->m_gpg_passphrase.IsEmpty()){
 		CPassPhraseDlg pf;
-		pf.SetFlag(GPG);
-		if(pf.DoModal() != IDOK)
+		if(pf.DoModal() == IDOK){
+			app->m_gpg_passphrase = pf.GetPass();
+		}else{
 			return;
+		}
 	}
 	CString pass = app->m_gpg_passphrase;
 
@@ -1019,7 +1030,8 @@ void CMainFrame::OnSettingGeneral()
 		}
 		else
 		{
-			m_notifyIcon.Delete();
+//			m_notifyIcon.Delete();
+			if (m_notifyIcon.IsActive()) m_notifyIcon.Delete();
 		}
 	}
 }
@@ -1190,10 +1202,10 @@ void CMainFrame::OnClose()
 
 BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct) 
 {
-	CString mailto;
+	CString opt;
 	if(pCopyDataStruct->dwData == WM_MAILTO){ 
-		mailto = (char *)pCopyDataStruct->lpData;
-		if(!mailto.IsEmpty() && mailto.Find("mailto:") == 0){
+		opt = (char *)pCopyDataStruct->lpData;
+		if(!opt.IsEmpty() && opt.Find("mailto:") == 0){
 			CPochyApp *app = (CPochyApp *)AfxGetApp();
 
 			// getting default account name
@@ -1202,11 +1214,11 @@ BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 			app->m_me.Initialize();
 
 			// setting To
-			if(mailto.Find("?", 7) != -1){ // mailto:hoge@hoge.com?subject=PGP%20Key&Body=Please%20send%20keyƂ
+			if(opt.Find("?", 7) != -1){ // mailto:hoge@hoge.com?subject=PGP%20Key&Body=Please%20send%20keyƂ
 					// subject, body is not implemented.
-				app->m_me.SetTo(mailto.Mid(7, mailto.Find("?", 7)-7));
+				app->m_me.SetTo(opt.Mid(7, opt.Find("?", 7)-7));
 			}else{
-				app->m_me.SetTo(mailto.Mid(7));
+				app->m_me.SetTo(opt.Mid(7));
 			}
 
 			if(!def_account.IsEmpty()){
@@ -1239,6 +1251,12 @@ BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 				// draftframe
 				app->CreateDraftFrame(this->m_pAcntV->GetFirstAccountName());
 			}
+		}else if(!opt.IsEmpty() && opt.Find("reply_q:") == 0){
+
+		}else if(!opt.IsEmpty() && opt.Find("reply_nq:") == 0){
+
+		}else if(!opt.IsEmpty() && opt.Find("forward:") == 0){
+
 		}
 	}
 	return CFrameWnd::OnCopyData(pWnd, pCopyDataStruct);
@@ -1327,3 +1345,22 @@ void CMainFrame::OnSysCommand(UINT nID, LPARAM lParam)
 		break;
 	}
 }
+
+void CMainFrame::StartTaskTrayAnimation()
+{
+	if(this->m_notifyIcon.IsActive()){
+		this->m_notifyIcon.StartAnimation();
+		this->m_tasktray_animation_num++;
+	}
+}
+
+void CMainFrame::StopTaskTrayAnimation()
+{
+	if(this->m_notifyIcon.IsActive()){
+		this->m_tasktray_animation_num--;
+		if(this->m_tasktray_animation_num == 0){
+			this->m_notifyIcon.EndAnimation();
+			this->m_notifyIcon.Modify();
+		}
+	}
+}
