@@ -43,6 +43,8 @@ public:
 
 // Cve[V
 public:
+	void StopTaskTrayAnimation();
+	void StartTaskTrayAnimation();
 	BOOL m_button_gpg_dec;
 	BOOL m_button_info;
 	BOOL m_button_transfer;
@@ -73,6 +75,10 @@ public:
 	virtual void AssertValid() const;
 	virtual void Dump(CDumpContext& dc) const;
 #endif
+private:
+	int m_tasktray_animation_num;
+	CNotifyIcon m_notifyIcon;
+	BOOL m_multipart_hide;
 
 protected:  // Rg[ o[po
 	CToolBar    m_wndToolBar;
@@ -80,7 +86,6 @@ protected:  // Rg[ o[po
 
 // ꂽbZ[W }bv֐
 protected:
-	BOOL m_multipart_hide;
 	//{{AFX_MSG(CMainFrame)
 	afx_msg LRESULT OnNotifyIcon(WPARAM wParam, LPARAM lParam);
 	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
@@ -122,8 +127,6 @@ protected:
 	//}}AFX_MSG
 	afx_msg void OnProgCreate();
 	DECLARE_MESSAGE_MAP()
-private:
-	CNotifyIcon m_notifyIcon;
 };
 
 /////////////////////////////////////////////////////////////////////////////
