@@ -7,9 +7,6 @@
 // PassPhraseDlg.h : wb_[ t@C
 //
 
-#define GPG (0)
-#define POP (1)
-
 /////////////////////////////////////////////////////////////////////////////
 // CPassPhraseDlg _CAO
 
@@ -17,7 +14,7 @@ class CPassPhraseDlg : public CDialog
 {
 // RXgNV
 public:
-	void SetFlag(int flag);
+	CString GetPass();
 	CPassPhraseDlg(CWnd* pParent = NULL);   // W̃RXgN^
 
 // _CAO f[^
@@ -44,7 +41,8 @@ protected:
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 private:
-	int m_flag;
+//	int m_flag;
+	CString m_pass;
 };
 
 //{{AFX_INSERT_LOCATION}}
