@@ -15,6 +15,7 @@
 #include "PassPhraseDlg.h"
 #include "lib.h"
 #include "DraftSendDlg.h"
+#include "md5ify.h"
 
 #define send_command(mes) \
 		send(Smtp.m_sock, command, command.GetLength(), 0);\
@@ -29,7 +30,6 @@
 
 UINT SendMail(LPVOID pParam)
 {
-//	CSock SmtpSocket;
 	CSmtp Smtp;
 	CSock PopSocket;
 	CString smtp_ip;
@@ -47,7 +47,7 @@ UINT SendMail(LPVOID pParam)
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
-	CListCtrl &lc = df->m_pListV2->GetListCtrl();
+	mf->StartTaskTrayAnimation();
 
 	// init@Ĉ߂̏
 	CString path = app->m_app_path + "\\" + df->m_account + "\\account.ini";
@@ -58,6 +58,7 @@ UINT SendMail(LPVOID pParam)
 		df->m_send_dlg->EndDialog(0);
 		df->m_send_dlg = NULL;
 		df->EnableWindow(TRUE);
+		mf->StopTaskTrayAnimation();
 		return FALSE;
 	}
 	if(df->m_me.GetFrom().IsEmpty()){
@@ -65,11 +66,12 @@ UINT SendMail(LPVOID pParam)
 		df->m_send_dlg->EndDialog(0);
 		df->m_send_dlg = NULL;
 		df->EnableWindow(TRUE);
+		mf->StartTaskTrayAnimation();
 		return FALSE;
 	}
 
 	// pop before smtpǂ
-	pop_before_smtp = GetPrivateProfileInt("pop", "pop_before_smtp", 0, path);
+	pop_before_smtp = GetPrivateProfileInt("smtp", "pop_before_smtp", 0, path);
 	if(pop_before_smtp){
 		try{
 			CString message;
@@ -85,43 +87,77 @@ UINT SendMail(LPVOID pParam)
 			df->m_send_dlg->m_status.SetWindowText(buf);
 			buf.Empty();
 
-			// user
+			// get user name from ini file.
 			CString pop_user;
 			GetPrivateProfileString("pop", "user", "", pop_user.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 			pop_user.ReleaseBuffer();
-			pop_user = "user " + g_cstr_chop2(pop_user) + "\r\n";
-			send(PopSocket.m_sock, pop_user.GetBuffer(10), pop_user.GetLength(), 0);
-			if(PopSocket.SockRead(buf) == -1){
-				throw "error is occured in user session";
-			}
-			df->m_send_dlg->m_status.SetWindowText(buf);
-			buf.Empty();
 
-			// pass
+			// get password from ini file.
 			CString pop_pass;
 			GetPrivateProfileString("pop", "pass", "", pop_pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 			pop_pass.ReleaseBuffer();
-			if(!pop_pass.IsEmpty())
-				pop_pass = "pass " + g_cstr_chop2(pop_pass) + "\r\n";
-			else if(pop_pass.IsEmpty() && !app->m_pop_passphrase.IsEmpty())
-				pop_pass = "pass " + app->m_pop_passphrase + "\r\n";
-			else if(pop_pass.IsEmpty() && app->m_pop_passphrase.IsEmpty()){
-				CPassPhraseDlg passDlg;
-				passDlg.SetFlag(POP);
-				passDlg.DoModal();
-				pop_pass = "pass " + app->m_pop_passphrase + "\r\n";
+			if(pop_pass.IsEmpty() && !mf->m_pAcntV->GetAccountPopPass(df->m_account).IsEmpty()){
+				pop_pass = mf->m_pAcntV->GetAccountPopPass(df->m_account);
+			}else if(pop_pass.IsEmpty() && mf->m_pAcntV->GetAccountPopPass(df->m_account).IsEmpty()){
+				// if getting no password from ini file, then show dialog for input password.
+				CPassPhraseDlg passDlg(df);
+				if(IDOK == passDlg.DoModal()){
+					pop_pass = passDlg.GetPass();
+					mf->m_pAcntV->SetAccountPopPass(df->m_account, pop_pass);
+				}else{
+					throw "";
+				}
 			}
-			send(PopSocket.m_sock, pop_pass.GetBuffer(10), pop_pass.GetLength(), 0);
-			if(PopSocket.SockRead(buf) == -1){
-				throw "error is occured in pass session";
+
+			CString md5_in;
+			CString md5_out;
+			CString apop;
+			if(GetPrivateProfileInt("pop", "apop", 0, path)){
+				// if using apop, below is done.
+				md5_in += pop_pass;
+				md5_out = MD5Digest((unsigned char *)md5_in.GetBuffer(0));
+				apop = "apop "+pop_user+" "+md5_out+"\r\n";
+				send(PopSocket.m_sock, apop.GetBuffer(0), apop.GetLength(), 0);
+				if(PopSocket.SockRead(buf) == -1)
+					throw "error is occured in pass session";
+				if(buf.Find("-ERR") == 0 || buf.Find("-err") == 0){
+					message.Format("%s", buf.GetBuffer(0));
+					pop_pass.Empty();
+					mf->m_pAcntV->SetAccountPopPass(df->m_account, pop_pass);
+					throw message.GetBuffer(0);
+				}
+				buf = apop;
+				df->m_send_dlg->m_status.SetWindowText(buf);
+				buf.Empty();
+			}else{
+				// below is normal authentification using user and pass command.
+				// user
+				pop_user = "user " + pop_user + "\r\n";
+				send(PopSocket.m_sock, pop_user.GetBuffer(10), pop_user.GetLength(), 0);
+				if(PopSocket.SockRead(buf) == -1)
+					throw "error is occured in user session";
+				if(buf.Find("-ERR") == 0 || buf.Find("-err") == 0){
+					message.Format("%s", buf.GetBuffer(0));
+					throw message.GetBuffer(0);
+				}
+				df->m_send_dlg->m_status.SetWindowText(buf);
+				buf.Empty();
+
+				// pass
+				pop_pass = "pass "+pop_pass+"\r\n";
+				send(PopSocket.m_sock, pop_pass.GetBuffer(0), pop_pass.GetLength(), 0);
+				if(PopSocket.SockRead(buf) == -1)
+					throw "error is occured in pass session";
+				if(buf.Find("-ERR") == 0 || buf.Find("-err") == 0){
+					message.Format("%s", buf.GetBuffer(0));
+					pop_pass.Empty();
+					mf->m_pAcntV->SetAccountPopPass(df->m_account, pop_pass);
+					throw message.GetBuffer(0);
+				}
+				buf = "pass ********";
+				df->m_send_dlg->m_status.SetWindowText(buf);
+				buf.Empty();
 			}
-			if(buf.Find("-ERR") == 0 || buf.Find("-err") == 0){
-				message.Format("%s", buf.GetBuffer(0));
-				throw message.GetBuffer(0);
-			}
-			buf = "pass ********";
-			df->m_send_dlg->m_status.SetWindowText(buf);
-			buf.Empty();
 
 			// quit
 			send(PopSocket.m_sock, "quit\r\n", strlen("quit\r\n"), 0);
@@ -133,14 +169,17 @@ UINT SendMail(LPVOID pParam)
 			send(PopSocket.m_sock, "quit\r\n", strlen("quit\r\n"), 0);
 			// socket
 			PopSocket.DisConnect();
-			df->MessageBox(errorstr, df->m_account+" - pop before smtp error");
+			if(strlen(errorstr)){
+				df->MessageBox(errorstr, df->m_account+" - pop before smtp error");
+			}
 			df->m_send_dlg->EndDialog(0);
 			df->m_send_dlg = NULL;
 			df->EnableWindow(TRUE);
+			mf->StopTaskTrayAnimation();
 			return FALSE;
 		}
 		// pop before smtp @\܂łɎԂ̂ŁAÔ
-		Sleep(10000);
+//		Sleep(10000);
 	}
 
 	try{
@@ -254,6 +293,7 @@ UINT SendMail(LPVOID pParam)
 		df->m_send_dlg->m_status.SetWindowText("");
 		df->m_send_dlg->EndDialog(0);
 		df->m_send_dlg = NULL;
+		mf->StopTaskTrayAnimation();
 		return FALSE;
 	}
 
@@ -268,5 +308,6 @@ UINT SendMail(LPVOID pParam)
 	df->m_send_dlg->EndDialog(0);
 	df->m_send_dlg = NULL;
 	PostMessage(df->m_hWnd, WM_COMMAND, WM_END, NULL);
+	mf->StopTaskTrayAnimation();
 	return TRUE;
 }
