@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2002-2003 chik, s.hiranaka
+ * 2003-10-26 Big modification is done for owner draw and etc by xken.
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -23,6 +24,17 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+#define SUMMARYVIEW_FILENAME _T("\\skin\\summaryview.bmp")
+//#define SUMMARYVIEW_TRANSPARENT_COLOR (RGB(128,128,128))
+#define SUMMARYVIEW_TRANSPARENT_COLOR (RGB(255,255,255))
+#define SUMMARYVIEW_ICON_READ (0)		// ǎ̃ACRԍ
+#define SUMMARYVIEW_ICON_SELECT (1)		// ĨACRԍ
+#define SUMMARYVIEW_ICON_UNREAD (2)		// ǎ̃ACRԍ
+#define SUMMARYVIEW_ICON_DELETE (3)		// 폜}[ÑACRԍ
+#define SUMMARYVIEW_ICON_ATTACH (4)		// Yt莞̃ACRԍ
+#define SUMMARYVIEW_RESICON_W (17)
+#define SUMMARYVIEW_RESICON_H (16)
+
 /////////////////////////////////////////////////////////////////////////////
 // CSummaryView
 
@@ -33,6 +45,18 @@ CSummaryView::CSummaryView()
 	this->m_stack_num = 0;
 	this->m_status_changed = FALSE;
 	this->m_index = -1;
+
+	m_bIconUsed = false;
+	m_IconImageHeight = 0;
+	m_IconImageWidth = 0;
+	m_ReadFontHeight = 16;
+	m_UnreadFontHeight = 16;
+	m_colReadText = 0;
+	m_colReadBk = 0;
+	m_colUnreadText = 0;
+	m_colUnreadBk = 0;
+	m_colSelectText = 0;
+	m_colSelectBk = 0;
 }
 
 CSummaryView::~CSummaryView()
@@ -55,6 +79,8 @@ BEGIN_MESSAGE_MAP(CSummaryView, CListView)
 	ON_COMMAND(ID_SUMMARYVIEW_HEADER_INFO, OnPopupHeaderInfo)
 	ON_COMMAND(ID_SUMMARYVIEW_RAWMAIL_INFO, OnPopupRawmailInfo)
 	ON_COMMAND(ID_SUMMARYVIEW_REBUILD, OnPopupRebuild)
+	ON_WM_KILLFOCUS()
+	ON_WM_MEASUREITEM_REFLECT()
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -102,26 +128,30 @@ void CSummaryView::OnInitialUpdate()
 	SetWindowLong(hWnd, GWL_STYLE, (dwStyle &~ LVS_TYPEMASK) | LVS_REPORT);
 	lc.SetExtendedStyle(LVS_EX_FULLROWSELECT);
 
+	// C[WXg̐ݒ
+	ReadIconImage();
+	SetIconUsed((app->GetProfileInt(_T("SummaryView"), _T("UseIcon"), 1) ? true : false));
+
 	// F̐ݒ
-	COLORREF m_colorEdit;
-	// wiF
-	m_colorEdit = RGB(
-		app->GetProfileInt("SummaryViewColor", "BkColorR", 0),
-		app->GetProfileInt("SummaryViewColor", "BkColorG", 0),
-		app->GetProfileInt("SummaryViewColor", "BkColorB", 0));
-	lc.SetBkColor(m_colorEdit);
-	// eLXg̔wiF
-	m_colorEdit = RGB(
-		app->GetProfileInt("SummaryViewColor", "BkColorR", DEF_BKG_COLOR_R),
-		app->GetProfileInt("SummaryViewColor", "BkColorG", DEF_BKG_COLOR_G),
-		app->GetProfileInt("SummaryViewColor", "BkColorB", DEF_BKG_COLOR_B));
-	lc.SetTextBkColor(m_colorEdit);
-	// ̐F
-	m_colorEdit = RGB(
-		app->GetProfileInt("SummaryViewColor", "TxtColorR", DEF_TXT_COLOR_R),
-		app->GetProfileInt("SummaryViewColor", "TxtColorG", DEF_TXT_COLOR_G),
-		app->GetProfileInt("SummaryViewColor", "TxtColorB", DEF_TXT_COLOR_B));
-	lc.SetTextColor(m_colorEdit);
+	COLORREF colDefReadText = RGB(DEF_TXT_COLOR_R, DEF_TXT_COLOR_G, DEF_TXT_COLOR_B);
+	COLORREF colDefReadBk = RGB(DEF_BKG_COLOR_R, DEF_BKG_COLOR_G, DEF_BKG_COLOR_B);
+	SetReadTextColor(ReadIniColor(_T("TxtColor"), colDefReadText));
+	SetReadBkColor(ReadIniColor(_T("BkColor"), colDefReadBk));
+	SetUnreadTextColor(ReadIniColor(_T("UnreadTxtColor"), m_colReadText));
+	SetUnreadBkColor(ReadIniColor(_T("UnreadBkColor"), m_colReadBk));
+	SetSelectTextColor(ReadIniColor(_T("SelectTxtColor"), GetSysColor(COLOR_HIGHLIGHTTEXT)));
+	SetSelectBkColor(ReadIniColor(_T("SelectBkColor"), GetSysColor(COLOR_HIGHLIGHT)));
+
+	// tHg̐ݒ
+	LOGFONT lf;
+	if (ReadIniFont(_T("ReadLogFont"), &lf) == false){
+		::GetObject(GetStockObject(DEFAULT_GUI_FONT), sizeof(LOGFONT), &lf);
+	}
+	SetReadFont(&lf);
+	if (ReadIniFont(_T("UnreadLogFont"), &lf) == false){
+		lf.lfWeight += 300;		// {[h
+	}
+	SetUnreadFont(&lf);
 
 	// Xgr[փJݒ
 	lvc.mask = LVCF_FMT|LVCF_TEXT|LVCF_WIDTH|LVCF_SUBITEM;
@@ -129,7 +159,7 @@ void CSummaryView::OnInitialUpdate()
 	for(i = 0; i < 5; i++){
 		lvc.pszText = Column[i];
 		num.Format("%d", i);
-		lvc.cx = app->GetProfileInt("SummaryViewColumn", num.GetBuffer(0), 100);
+		lvc.cx = app->GetProfileInt(_T("SummaryViewColumn"), num.GetBuffer(0), 100);
 		if(lvc.cx > 1000){
 			lvc.cx = 100;
 		}
@@ -138,6 +168,9 @@ void CSummaryView::OnInitialUpdate()
 
 	// Xgr[փf[^i[
 	m_index = -1;
+
+	// Xgr[XV
+	UpdateSummaryView();
 }
 
 void CSummaryView::OnGetdispinfo(NMHDR* pNMHDR, LRESULT* pResult) 
@@ -182,7 +215,8 @@ BOOL CSummaryView::PreCreateWindow(CREATESTRUCT& cs)
 	cs.style	|= LVS_OWNERDATA 
 				| LVS_REPORT 
 				/*| LVS_SINGLESEL*/ 
-				| LVS_SHOWSELALWAYS;
+				| LVS_SHOWSELALWAYS
+				| LVS_OWNERDRAWFIXED;	// I[i[`
 	// LVS_SORTDESCENDING  LVS_SORTASCENDING
 
 	return CListView::PreCreateWindow(cs);
@@ -666,6 +700,10 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 void CSummaryView::OnSetFocus(CWnd* pOldWnd) 
 {
 	CListView::OnSetFocus(pOldWnd);
+
+	// ACeĕ`悵ĕύX\
+	if (pOldWnd != NULL && pOldWnd->GetParent() == this) return;
+	if ((GetStyle() & LVS_TYPEMASK) == LVS_REPORT) RepaintSelectedItems();
 }
 
 void CSummaryView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult) 
@@ -1712,3 +1750,370 @@ void CSummaryView::GetSelectedMail(CUIntArray &index_array)
 		index_array.Add(this->GetListCtrl().GetNextSelectedItem(pos));
 	}
 }
+
+void CSummaryView::OnKillFocus(CWnd* pNewWnd)
+{
+	CListView::OnKillFocus(pNewWnd);
+
+	// ACeĕ`悵ĕύX\
+	if (pNewWnd != NULL && pNewWnd->GetParent() == this) return;
+	if ((GetStyle() & LVS_TYPEMASK) == LVS_REPORT) RepaintSelectedItems();
+}
+
+void CSummaryView::MeasureItem(LPMEASUREITEMSTRUCT lpMeasureItemStruct)
+{
+	// ACe̍Zbg
+	int iHeight = 0;
+	if (iHeight < m_ReadFontHeight) iHeight = m_ReadFontHeight;
+	if (iHeight < m_UnreadFontHeight) iHeight = m_UnreadFontHeight;
+	if (m_bIconUsed && iHeight < m_IconImageHeight) iHeight = m_IconImageHeight;
+	lpMeasureItemStruct->itemHeight = iHeight;
+}
+
+void CSummaryView::DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
+{
+	static _TCHAR szBuff[512];	// Œobt@TCYɒ
+	BOOL bFocus, bSelected;
+	COLORREF colText, colBk, colIconBk;
+	CFont* pFontSave;
+	COLORREF colTextSave, colBkSave;
+	LPCTSTR pszText;
+
+	CListCtrl& cListCtrl = GetListCtrl();
+	CDC* pDC = CDC::FromHandle(lpDrawItemStruct->hDC);
+	int nItem = lpDrawItemStruct->itemID;
+
+	bool bIconUsed = m_bIconUsed;
+	if (m_IconImage.m_hImageList == NULL) bIconUsed = false;
+
+	// ACef[^擾
+	LV_ITEM lvItem;
+	lvItem.mask = LVIF_TEXT | LVIF_IMAGE | LVIF_STATE;
+	lvItem.iItem = nItem;
+	lvItem.iSubItem = 0;
+	lvItem.pszText = szBuff;
+	lvItem.cchTextMax = sizeof(szBuff);
+	lvItem.stateMask = 0xFFFF;
+	cListCtrl.GetItem(&lvItem);
+
+	// [Xe[^X擾
+	bool bMailUnread = (szBuff[0] == 'N');		// 
+	bool bMailDelete = (szBuff[0] == 'D');		// 폜
+	bool bMailAttach = (szBuff[1] == 'M');		// Yt
+
+	// IԂ̎擾
+	bFocus = (GetFocus() == this);
+	bSelected = (bFocus || (GetStyle() & LVS_SHOWSELALWAYS)) && lvItem.state & LVIS_SELECTED;
+	bSelected = bSelected || (lvItem.state & LVIS_DROPHILITED);
+
+	// tHgƃJ[ݒ
+	if (!bMailUnread){
+		pFontSave = pDC->SelectObject(&m_cReadFont);
+		colText = ((bSelected) ? m_colSelectText : m_colReadText);
+		colBk = ((bSelected) ? m_colSelectBk : m_colReadBk);
+		colIconBk = m_colReadBk;
+	} else {
+		pFontSave = pDC->SelectObject(&m_cUnreadFont);
+		colText = ((bSelected) ? m_colSelectText : m_colUnreadText);
+		colBk = ((bSelected) ? m_colSelectBk : m_colUnreadBk);
+		colIconBk = m_colUnreadBk;
+	}
+	colTextSave = pDC->SetTextColor(colText);
+	colBkSave = pDC->SetBkColor(colBk);
+
+	CRect rcLabel, rcAllLabels;
+	cListCtrl.GetItemRect(nItem, rcLabel, LVIR_LABEL);
+	cListCtrl.GetItemRect(nItem, rcAllLabels, LVIR_BOUNDS);
+
+	// ACR`
+	if (bIconUsed){
+		
+		CPoint cPos(rcLabel.left, rcLabel.top);
+		pDC->FillRect(rcLabel, &CBrush(colIconBk));
+		
+		// YtACR
+		if (cPos.x < rcLabel.right){
+			if (bMailAttach) m_IconImage.Draw(pDC, SUMMARYVIEW_ICON_ATTACH, cPos, ILD_TRANSPARENT);
+		}
+		cPos.x += m_IconImageWidth;
+
+		// ǁIǁ폜ACR
+		if (cPos.x < rcLabel.right){
+			int iIcon = SUMMARYVIEW_ICON_READ;
+			if (bMailUnread) iIcon = SUMMARYVIEW_ICON_UNREAD;
+			if (bMailDelete) iIcon = SUMMARYVIEW_ICON_DELETE;
+			if (bSelected) iIcon = SUMMARYVIEW_ICON_SELECT;
+			m_IconImage.Draw(pDC, iIcon, cPos, ILD_TRANSPARENT);
+		}
+		
+		rcAllLabels.left = rcLabel.right;
+		
+	}
+
+	// s̔wiNA
+	pDC->FillRect(rcAllLabels, &CBrush(colBk));
+
+	// ŏ̃J̕`(ACRgp)
+	if (!bIconUsed){
+		int iOffsetFirst = 2;
+		pszText = MakeShortString(pDC, szBuff, (rcLabel.right-rcLabel.left), (iOffsetFirst*2));
+		rcLabel.left += iOffsetFirst;
+		rcLabel.right -= iOffsetFirst;
+		pDC->DrawText(
+			pszText, -1, rcLabel,
+			(DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_NOCLIP | DT_VCENTER)
+		);
+	}
+
+	// QԖڈȍ~̃J̕`
+	CRect rcColumn;
+	LV_COLUMN lvColumn;
+	int iOffsetOther = 6;
+	lvColumn.mask = (LVCF_FMT | LVCF_WIDTH);
+	cListCtrl.GetItemRect(nItem, rcColumn, LVIR_LABEL);
+	for(int nColumn = 1; cListCtrl.GetColumn(nColumn, &lvColumn); nColumn++){
+		
+		rcColumn.left = rcColumn.right;
+		rcColumn.right += lvColumn.cx;
+		if (cListCtrl.GetItemText(nItem, nColumn, szBuff, sizeof(szBuff)) == 0) continue;
+		
+		UINT nJustify = DT_LEFT;
+		pszText = MakeShortString(pDC, szBuff, (rcColumn.right-rcColumn.left), (iOffsetOther*2));
+		if(pszText == szBuff){
+			switch(lvColumn.fmt & LVCFMT_JUSTIFYMASK){
+			case LVCFMT_RIGHT:
+				nJustify = DT_RIGHT;
+				break;
+			case LVCFMT_CENTER:
+				nJustify = DT_CENTER;
+				break;
+			default:
+				break;
+			}
+		}
+		
+		rcLabel = rcColumn;
+		rcLabel.left += iOffsetOther;
+		rcLabel.right -= iOffsetOther;
+		pDC->DrawText(
+			pszText, -1, rcLabel,
+			(nJustify | DT_SINGLELINE | DT_NOPREFIX | DT_NOCLIP | DT_VCENTER)
+		);
+		
+	}
+
+	// tH[JX``
+	if ((lvItem.state & LVIS_FOCUSED) && bFocus) pDC->DrawFocusRect(rcAllLabels);
+
+	// foCXReLXg̑߂
+	pDC->SetBkColor(colBkSave);
+	pDC->SetTextColor(colTextSave);
+	pDC->SelectObject(pFontSave);
+}
+
+LPCTSTR CSummaryView::MakeShortString(CDC* pDC, LPCTSTR lpszLong, int nColumnLen, int nOffset)
+{
+	static _TCHAR szShort[512];		// Œobt@TCYɒ
+	static const _TCHAR szThreeDots[] = _T("...");
+
+	int nStringLen = lstrlen(lpszLong);
+	if(nStringLen == 0 || (pDC->GetTextExtent(lpszLong, nStringLen).cx + nOffset) <= nColumnLen){
+		return(lpszLong);
+	}
+
+	int i, j;
+	int nAddLen = pDC->GetTextExtent(szThreeDots, sizeof(szThreeDots)).cx;
+
+	i = j = 0;
+	while(lpszLong[i] != 0){
+		j = i;
+		
+		if (_istlead(lpszLong[i]) != 0){
+			szShort[i+0] = lpszLong[i+0];
+			szShort[i+1] = lpszLong[i+1];
+			i += 2;
+		} else {
+			szShort[i+0] = lpszLong[i+0];
+			i++;
+		}
+		szShort[i] = 0;
+		
+		if((pDC->GetTextExtent(szShort, i).cx + nOffset + nAddLen) > nColumnLen){
+			szShort[j] = 0;
+			break;
+		}
+		
+	}
+	lstrcat(szShort, szThreeDots);
+
+	return(szShort);
+}
+
+void CSummaryView::RepaintSelectedItems(void)
+{
+	CRect rcItem, rcLabel;
+	CListCtrl& cListCtrl = GetListCtrl();
+
+	int nItem = cListCtrl.GetNextItem(-1, LVNI_FOCUSED);
+
+	if(nItem != -1){
+		cListCtrl.GetItemRect(nItem, rcItem, LVIR_BOUNDS);
+		cListCtrl.GetItemRect(nItem, rcLabel, LVIR_LABEL);
+		rcItem.left = rcLabel.left;
+		InvalidateRect(rcItem, FALSE);
+	}
+
+	if(!(GetStyle() & LVS_SHOWSELALWAYS)){
+		for(nItem = cListCtrl.GetNextItem(-1, LVNI_SELECTED);
+			nItem != -1; nItem = cListCtrl.GetNextItem(nItem, LVNI_SELECTED)){
+			cListCtrl.GetItemRect(nItem, rcItem, LVIR_BOUNDS);
+			cListCtrl.GetItemRect(nItem, rcLabel, LVIR_LABEL);
+			rcItem.left = rcLabel.left;
+			InvalidateRect(rcItem, FALSE);
+		}
+	}
+
+	UpdateWindow();
+}
+
+void CSummaryView::ReadIconImage(void)
+{
+	CString strFilePath;
+	HBITMAP hBitmap;
+
+	// XLt@C̓ǂݍ
+	strFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + SUMMARYVIEW_FILENAME;
+	hBitmap = (HBITMAP)::LoadImage(NULL, strFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
+
+	// C[WXgɐݒ
+	if (hBitmap != NULL){
+		CBitmap* pBitmap = CBitmap::FromHandle(hBitmap);
+		if (pBitmap != NULL){
+			BITMAP bitmap;
+			if (pBitmap->GetBitmap(&bitmap) != 0){
+				int iWidth = (bitmap.bmWidth / 5);
+				int iHeight = bitmap.bmHeight;
+				if (m_IconImage.Create(iWidth, iHeight, ILC_COLOR8|ILC_MASK, 0, 5)){
+					m_IconImage.Add(pBitmap, SUMMARYVIEW_TRANSPARENT_COLOR);
+					m_IconImageHeight = iHeight;
+					m_IconImageWidth = iHeight;
+				}
+			}
+		}
+		::DeleteObject(hBitmap);
+		return;
+	}
+
+	// \[X̓ǂݍ
+	if (m_IconImage.Create(SUMMARYVIEW_RESICON_W, SUMMARYVIEW_RESICON_H, ILC_COLOR8|ILC_MASK, 0, 5)){
+		CBitmap bmp;
+		if(bmp.LoadBitmap(IDB_SUMMARYVIEW)){
+			m_IconImage.Add(&bmp, SUMMARYVIEW_TRANSPARENT_COLOR);
+			m_IconImageHeight = SUMMARYVIEW_RESICON_H;
+			m_IconImageWidth = SUMMARYVIEW_RESICON_W;
+		}
+		bmp.DeleteObject();
+	}
+}
+
+COLORREF CSummaryView::ReadIniColor(LPCTSTR lpszKeyName, COLORREF colDefault)
+{
+	int r, g, b;
+	_TCHAR szKeyName[64];
+
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+
+	lstrcpy(szKeyName, lpszKeyName);
+	lstrcat(szKeyName, _T("R"));
+	r = app->GetProfileInt(_T("SummaryViewColor"), szKeyName, GetRValue(colDefault));
+
+	lstrcpy(szKeyName, lpszKeyName);
+	lstrcat(szKeyName, _T("G"));
+	g = app->GetProfileInt(_T("SummaryViewColor"), szKeyName, GetGValue(colDefault));
+
+	lstrcpy(szKeyName, lpszKeyName);
+	lstrcat(szKeyName, _T("B"));
+	b = app->GetProfileInt(_T("SummaryViewColor"), szKeyName, GetBValue(colDefault));
+
+	return RGB(r, g, b);
+}
+
+bool CSummaryView::ReadIniFont(LPCTSTR lpszKeyName, LOGFONT* lpLogFont)
+{
+	LPBYTE pData;
+	UINT nSize;
+
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	if(app->GetProfileBinary(_T("SummaryViewFont"), lpszKeyName, &pData, &nSize)){
+		ASSERT(nSize == sizeof(LOGFONT));
+		::CopyMemory(lpLogFont, pData, sizeof(LOGFONT));
+		delete [] pData;
+		return true;
+	}
+
+	return false;
+}
+
+void CSummaryView::UpdateSummaryView(void)
+{
+	CRect rcRect;
+	GetWindowRect(&rcRect);
+
+	WINDOWPOS WinPos;
+	ZeroMemory(&WinPos, sizeof(WINDOWPOS));
+	WinPos.hwnd = GetSafeHwnd();
+	WinPos.cx = rcRect.Width();
+	WinPos.cy = rcRect.Height();
+	WinPos.flags = SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOZORDER;
+
+	// WM_MEASUREITEMbZ[W𔭍sׂɍs
+	SendMessage(WM_WINDOWPOSCHANGED, 0, (LPARAM)&WinPos);
+}
+
+void CSummaryView::SetIconUsed(bool bUsed)
+{
+	m_bIconUsed = bUsed;
+}
+
+void CSummaryView::SetReadFont(const LOGFONT* lpLogFont)
+{
+	m_ReadFontHeight = abs(lpLogFont->lfHeight);
+	m_cReadFont.CreateFontIndirect(lpLogFont);
+}
+
+void CSummaryView::SetUnreadFont(const LOGFONT* lpLogFont)
+{
+	m_UnreadFontHeight = abs(lpLogFont->lfHeight);
+	m_cUnreadFont.CreateFontIndirect(lpLogFont);
+}
+
+void CSummaryView::SetReadTextColor(COLORREF colColor)
+{
+	m_colReadText = colColor;
+}
+
+void CSummaryView::SetReadBkColor(COLORREF colColor)
+{
+	m_colReadBk = colColor;
+	GetListCtrl().SetBkColor(colColor);
+}
+
+void CSummaryView::SetUnreadTextColor(COLORREF colColor)
+{
+	m_colUnreadText = colColor;
+}
+
+void CSummaryView::SetUnreadBkColor(COLORREF colColor)
+{
+	m_colUnreadBk = colColor;
+}
+
+void CSummaryView::SetSelectTextColor(COLORREF colColor)
+{
+	m_colSelectText = colColor;
+}
+
+void CSummaryView::SetSelectBkColor(COLORREF colColor)
+{
+	m_colSelectBk = colColor;
+}
