@@ -35,7 +35,24 @@ public:
 private:
 	int m_unread;
 	int SetStack(CString path);
-//	CImageList* m_image;
+
+	CImageList m_IconImage;
+	CFont m_cReadFont;
+	CFont m_cUnreadFont;
+
+	bool m_bIconUsed;
+
+	int m_IconImageHeight;
+	int m_IconImageWidth;
+	int m_ReadFontHeight;
+	int m_UnreadFontHeight;
+
+	COLORREF m_colReadText;
+	COLORREF m_colReadBk;
+	COLORREF m_colUnreadText;
+	COLORREF m_colUnreadBk;
+	COLORREF m_colSelectText;
+	COLORREF m_colSelectBk;
 
 // Iy[V
 public:
@@ -62,6 +79,25 @@ public:
 	void DeleteMail(CUIntArray &index_array);
 	void WriteList(); // write out m_array_list into list file
 
+public:
+	void ReadIconImage(void);
+	void UpdateSummaryView(void);
+	void SetIconUsed(bool bUsed);
+	void SetReadFont(const LOGFONT* lpLogFont);
+	void SetUnreadFont(const LOGFONT* lpLogFont);
+	void SetReadTextColor(COLORREF colColor);
+	void SetReadBkColor(COLORREF colColor);
+	void SetUnreadTextColor(COLORREF colColor);
+	void SetUnreadBkColor(COLORREF colColor);
+	void SetSelectTextColor(COLORREF colColor);
+	void SetSelectBkColor(COLORREF colColor);
+
+private:
+	LPCTSTR MakeShortString(CDC* pDC, LPCTSTR lpszLong, int nColumnLen, int nOffset);
+	void RepaintSelectedItems(void);
+	COLORREF ReadIniColor(LPCTSTR lpszKeyName, COLORREF colDefault);
+	bool ReadIniFont(LPCTSTR lpszKeyName, LOGFONT* lpLogFont);
+
 // I[o[Ch
 	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
 
@@ -73,6 +109,8 @@ public:
 	protected:
 	virtual void OnDraw(CDC* pDC);	// ̃r[`悷邽߂ɃI[o[Ch܂B
 	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
+	virtual void MeasureItem(LPMEASUREITEMSTRUCT lpMeasureItemStruct);
+	virtual void DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct);
 	//}}AFX_VIRTUAL
 
 // Cve[V
@@ -99,6 +137,7 @@ protected:
 	afx_msg void OnPopupHeaderInfo();
 	afx_msg void OnPopupRawmailInfo();
 	afx_msg void OnPopupRebuild();
+	afx_msg void OnKillFocus(CWnd* pNewWnd);
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 };
