@@ -334,7 +334,7 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 
 void CTextView::DisplayPart(int part)
 {
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
+//	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CStringArray body;
 	CString message;
 	CString header;
@@ -615,6 +615,9 @@ void CTextView::OnPopupBrowser()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CStringArray body;
+
+	if(this->m_current_part == -1) return;
+
 	this->m_md.GetBody(this->m_current_part, body);
 
 	CString buf;
