@@ -43,7 +43,7 @@ CPochyApp::CPochyApp()
 	CGpg gpg;
 	m_gpg_enable = gpg.Check();
 	m_gpg_passphrase.Empty();
-	m_pop_passphrase.Empty();
+//	m_pop_passphrase.Empty();
 	// toolbarreplyAtransferAheaderAgpg{^𖳌ɂ
 }
 
@@ -150,7 +150,14 @@ BOOL CPochyApp::InitInstance()
 		return FALSE;
 
 	// C EBhEꂽ̂ŁA\ƍXVs܂B
-	this->m_pMainWnd->ShowWindow(SW_SHOW);
+	if(this->GetProfileInt("Customize", "Minimize", 0)){
+		this->m_pMainWnd->ShowWindow(SW_SHOW);
+		this->m_pMainWnd->ShowWindow(SW_MINIMIZE);
+		if(this->GetProfileInt("TaskTray", "TaskTrayOnly", 0) ||
+			this->GetProfileInt("TaskTray", "UseTaskTray", 0)){
+			this->m_pMainWnd->ShowWindow(SW_HIDE);	
+		}
+	}
 	this->m_pMainWnd->UpdateWindow();
 
 	// EBhẼvpeBXgɃj[NȏǉƂ
