@@ -26,7 +26,7 @@
 #define HT_LIST2 (20)
 #define HT_FILELIST (140)
 #define HT_MULTI_HEIGHT (60)			// height of multipartview
-#define HT_ATTACHED_HEIGHT (26)			// draftframe̓Ytt@C\view̍
+#define HT_ATTACHED_HEIGHT (30)			// draftframe̓Ytt@C\view̍
 #define HT_SPLIT_LINE (7)				// splitter̋Ȇ
 #define HT_SPLIT_FRAME (2)				// splitter̃t[̑
 #define HT_HEAD (120)					// draftframeaddress̍
@@ -49,11 +49,11 @@
 #define DEF_BOXNAME_DRAFT "e"
 #define DEF_BOXNAME_TRASH "S~"
 #ifdef _IPV6_
-#define X_MAILER "Pochy 0.1.5 (KotaKinabalu) IPv6 ready"
-#define VERSION "Pochy 0.1.5 (KotaKinabalu) IPv6 ready"
+#define X_MAILER "Pochy 0.1.6 IPv6 ready"
+#define VERSION "Pochy 0.1.6 IPv6 ready"
 #else
-#define X_MAILER "Pochy 0.1.5 (KotaKinabalu)"
-#define VERSION "Pochy 0.1.5 (KotaKinabalu)"
+#define X_MAILER "Pochy 0.1.6"
+#define VERSION "Pochy 0.1.6"
 #endif
 #define COPYRIGHT "Copyright (C) 2003 Pochy project team"
 #define CONTRIBUTORS "\
@@ -82,6 +82,14 @@ From=hoge@hoge.com\r\n\
 # ݂̂ƂAU蕪ɂ̓wb_񂵂pł܂B\r\n\
 # ҏWA㏑ۑĂB\r\n"
 
+#define WM_USER_NOTIFYICON (WM_APP + 100)
+#define TOOLBAR_MAIN_FILENAME _T("\\skin\\toolbar_main.bmp")
+#define TASKTRAY_ICON_FILENAME _T("\\skin\\tasktray.ico")
+#define TASKTRAY_ANIMATION_FILENAME _T("\\skin\\tasktrayanimation.bmp")
+#define TASKTRAY_ANIMATION_TIMER_ID (200)
+#define NUMBER_OF_TOOLBAR_MAIN_ICON (10)
+
+
 #define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()
 
 /////////////////////////////////////////////////////////////////////////////
@@ -120,7 +128,7 @@ public:
 	BOOL m_retrieving;
 	BOOL m_gpg_enable;
 	BOOL m_ipv6_enable;
-	CString m_pop_passphrase;
+//	CString m_pop_passphrase;
 	CMimeEncode m_me;
 private:
 };
